@@ -726,7 +726,9 @@ class TestPermissions:
             fields=KEYS("id", "name", "in_admin"), admin=ANY(BaseModelAdmin)
         )
         assert orm_models["core.Normal"] == OrmModel(
-            fields=KEYS("admin", "id", "name", "in_admin", "inline_admin"),
+            fields=KEYS(
+                "admin", "id", "name", "in_admin", "inline_admin", "not_in_admin"
+            ),
             admin=ANY(BaseModelAdmin),
         )
 
@@ -738,7 +740,10 @@ class TestPermissions:
         assert "core.InAdmin" not in orm_models
         assert "core.InlineAdmin" not in orm_models
         assert orm_models["core.Normal"] == OrmModel(
-            fields=KEYS("admin", "id", "name"), admin=ANY(BaseModelAdmin)
+            fields=KEYS(
+                "admin", "id", "name", "in_admin", "inline_admin", "not_in_admin"
+            ),
+            admin=ANY(BaseModelAdmin),
         )
 
     @pytest.mark.django_db
@@ -749,7 +754,10 @@ class TestPermissions:
         assert "core.InAdmin" not in orm_models
         assert "core.InlineAdmin" not in orm_models
         assert orm_models["core.Normal"] == OrmModel(
-            fields=KEYS("admin", "id", "name"), admin=ANY(BaseModelAdmin)
+            fields=KEYS(
+                "admin", "id", "name", "in_admin", "inline_admin", "not_in_admin"
+            ),
+            admin=ANY(BaseModelAdmin),
         )
 
     @pytest.mark.django_db
@@ -762,7 +770,10 @@ class TestPermissions:
         )
         assert "core.InlineAdmin" not in orm_models
         assert orm_models["core.Normal"] == OrmModel(
-            fields=KEYS("admin", "id", "name", "in_admin"), admin=ANY(BaseModelAdmin)
+            fields=KEYS(
+                "admin", "id", "name", "in_admin", "inline_admin", "not_in_admin"
+            ),
+            admin=ANY(BaseModelAdmin),
         )
 
 
@@ -770,7 +781,7 @@ class TestPermissions:
 @pytest.mark.parametrize(
     "lookup,value",
     [
-        ("", "2020-01-02 03:04:05.000006"),
+        ("", "2020-01-02 03:04:05"),
         ("year", 2020),
         ("quarter", 1),
         ("month", "January"),
@@ -876,11 +887,11 @@ def test_string_choice_field(get_product_flat):
     models.Product.objects.create(producer=producer, string_choice="a")
     models.Product.objects.create(producer=producer, string_choice="b")
 
-    data = get_product_flat(1, f"string_choice", {"string_choice__equals": ["A"]})
+    data = get_product_flat(1, "string_choice", {"string_choice__equals": ["A"]})
     assert data == [["A"]]
 
     data = get_product_flat(
-        1, f"string_choice__raw", {"string_choice__raw__equals": ["a"]}
+        1, "string_choice__raw", {"string_choice__raw__equals": ["a"]}
     )
     assert data == [["a"]]
 
@@ -890,11 +901,11 @@ def test_number_choice_field(get_product_flat):
     models.Product.objects.create(producer=producer, number_choice=1)
     models.Product.objects.create(producer=producer, number_choice=2)
 
-    data = get_product_flat(1, f"number_choice", {"number_choice__equals": ["A"]})
+    data = get_product_flat(1, "number_choice", {"number_choice__equals": ["A"]})
     assert data == [["A"]]
 
     data = get_product_flat(
-        1, f"number_choice__raw", {"number_choice__raw__equals": [1]}
+        1, "number_choice__raw", {"number_choice__raw__equals": [1]}
     )
     assert data == [[1]]
 
